@@ -15,12 +15,14 @@ from django.conf import settings
 from django.contrib.auth import authenticate
 from django.contrib.auth import get_user_model
 from django.core.cache import cache
+from django.core.exceptions import ObjectDoesNotExist
 from django.core.exceptions import ValidationError as CoreValidationError
 from django.utils import timezone
 from django.utils.translation import gettext_lazy as _
 from oasis.models import Client
 from oasis_auth.lib.utils import AuthActions
 from oasis_auth.lib.utils import SendCode
+from rest_framework import permissions
 from rest_framework import status
 from rest_framework.response import Response
 from uuid import uuid4
@@ -41,6 +43,7 @@ class OasisAuthServices(ViewSet):
     __cache_timeout = settings.OASIS_AUTH_CODE_TIMEOUT
     __cache_timeout_seconds = __cache_timeout * 60
     __user = get_user_model()
+    permission_classes = [permissions.AllowAny]
 
     def register(self, request) -> Response:
         """
@@ -109,8 +112,9 @@ class OasisAuthServices(ViewSet):
         except APIException as exc:
             raise APIException(msg=exc.detail.get("message"), error=exc.detail.get("error"),
                                http_status=exc.status_code) from exc
-        except self.__user.DoesNotExist as exc:
-            raise APIException(msg=_("Customer does not exist."), http_status=status.HTTP_400_BAD_REQUEST) from exc
+        except ObjectDoesNotExist as exc:
+            raise APIException(msg=_("Customer does not exist."), error=str(exc),
+                               http_status=status.HTTP_400_BAD_REQUEST) from exc
         except ValidationError as exc:
             raise APIException(msg=exc.detail[0], error="register", http_status=exc.status_code) from exc
         except Exception as exc:
@@ -197,7 +201,12 @@ class OasisAuthServices(ViewSet):
                 raise ValidationError(ErrorMessages.DATA_REQUEST_NOT_FOUND)
         except ValidationError as exc:
             raise APIException(msg=exc.detail[0], error="login", http_status=exc.status_code) from exc
-        except self.__user.DoesNotExist:
-            raise AuthenticationFailed(_("Email or Password incorrect."))
+        except self.__user.DoesNotExist as exc:
+            raise APIException(msg=_("Email or Password incorrect."), error="login",
+                               http_status=status.HTTP_401_UNAUTHORIZED) from exc
+        except AuthenticationFailed as exc:
+            raise APIException(msg=exc.detail, error="login", http_status=exc.status_code) from exc
+        except Exception as exc:
+            raise APIException(msg=str(exc), error="login", http_status=status.HTTP_500_INTERNAL_SERVER_ERROR) from exc
         else:
             return Response(status=status_return, data=data_return)
