@@ -15,8 +15,6 @@ from django.utils.translation import gettext_lazy as _
 from django.core.exceptions import ValidationError
 from oasis_auth.models import UserProfile
 from rest_framework_simplejwt.tokens import RefreshToken
-from rest_framework_simplejwt.settings import api_settings
-from rest_framework_simplejwt.serializers import TokenObtainSerializer
 from typing import Any
 
 
